summaryrefslogtreecommitdiff
path: root/utils/TableGen/Record.h
diff options
context:
space:
mode:
Diffstat (limited to 'utils/TableGen/Record.h')
-rw-r--r--utils/TableGen/Record.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/utils/TableGen/Record.h b/utils/TableGen/Record.h
index ecd6d7020a..9f30004167 100644
--- a/utils/TableGen/Record.h
+++ b/utils/TableGen/Record.h
@@ -1000,11 +1000,11 @@ public:
///
ListInit *getValueAsListInit(const std::string &FieldName) const;
/// getValueAsListDef - This method looks up the specified field and returns
/// its value as a vector of records, throwing an exception if the field does
/// not exist or if the value is not the right type.
///
- std::vector<Record*> getValueAsListDef(const std::string &FieldName) const;
+ std::vector<Record*> getValueAsListOfDefs(const std::string &FieldName) const;
/// getValueAsDef - This method looks up the specified field and returns its
/// value as a Record, throwing an exception if the field does not exist or if
@@ -1000,11 +1000,11 @@ public:
///
ListInit *getValueAsListInit(const std::string &FieldName) const;
- /// getValueAsListDef - This method looks up the specified field and returns
- /// its value as a vector of records, throwing an exception if the field does
- /// not exist or if the value is not the right type.
+ /// getValueAsListOfDefs - This method looks up the specified field and
+ /// returnsits value as a vector of records, throwing an exception if the
+ /// field does not exist or if the value is not the right type.
///